@@ -37,6 +37,7 @@ from debputy.manifest_parser.parser_doc import render_rule
 from debputy.manifest_parser.tagging_types import TypeMapping
 from debputy.manifest_parser.util import unpack_type, AttributePath
 from debputy.packager_provided_files import detect_all_packager_provided_files
+from debputy.plugin.api.doc_parsing import parser_type_name
 from debputy.plugin.api.example_processing import (
     process_discard_rule_example,
     DiscardVerdict,
@@ -428,12 +429,6 @@ def list_manifest_variable_arg_parser(
     TEXT_ONLY_FORMAT(plugin_list_manifest_variables_parser)
 
 
-def _parser_type_name(v: Union[str, Type[Any]]) -> str:
-    if isinstance(v, str):
-        return v if v != "<ROOT>" else ""
-    return v.__name__
-
-
 @plugin_list_cmds.register_subcommand(
     ["pluggable-manifest-rules", "p-m-r", "pmr"],
     help_description="Pluggable manifest rules (such as install rules)",
@@ -461,7 +456,7 @@ def _plugin_cmd_list_manifest_rules(context: CommandContext) -> None:
             [
                 (
                     rn,
-                    _parser_type_name(rt),
+                    parser_type_name(rt),
                     pt.parser_for(rn).plugin_metadata.plugin_name,
                 )
                 for rt, pt in parsers
@@ -805,7 +800,7 @@ def lookup_pmr_rule(
     )
 
     for rule_type, dispatching_parser in parsers:
-        if req_rule_type is not None and req_rule_type not in _parser_type_name(
+        if req_rule_type is not None and req_rule_type not in parser_type_name(
             rule_type
         ):
             continue
@@ -823,7 +818,7 @@ def lookup_pmr_rule(
         raise UnresolvableRuleError(
             f"The name {rule_name} was ambiguous and matched multiple rule types.  Please use"
             f" <rule-type>::{rule_name} to clarify which rule to use"
-            f" (such as {_parser_type_name(match_a)}::{rule_name} or {_parser_type_name(match_b)}::{rule_name})."
+            f" (such as {parser_type_name(match_a)}::{rule_name} or {parser_type_name(match_b)}::{rule_name})."
             f" Please use `debputy plugin list pluggable-manifest-rules` to see the list of rules."
         )
 
@@ -834,13 +829,13 @@ def lookup_pmr_rule(
             manifest_attribute_path = rule_type
         else:
             manifest_attribute_path = SUPPORTED_DISPATCHABLE_TABLE_PARSERS[rule_type]
-        parser_type_name = _parser_type_name(rule_type)
+        full_parser_type_name = parser_type_name(rule_type)
         parser = plugin_provided_parser.parser
         plugin_metadata = plugin_provided_parser.plugin_metadata
     else:
         rule_name = "::"
         parser = parser_generator.dispatchable_object_parsers[OPARSER_MANIFEST_ROOT]
-        parser_type_name = ""
+        full_parser_type_name = ""
         plugin_metadata = plugin_metadata_for_debputys_own_plugin()
         manifest_attribute_path = ""
 
@@ -848,7 +843,7 @@ def lookup_pmr_rule(
     return PMRRuleLookup(
         rule_name,
         parser,
-        parser_type_name,
+        full_parser_type_name,
         plugin_metadata,
         is_root_rule,
         manifest_attribute_path,
