@@ -10,12 +10,12 @@ from debputy.commands.debputy_cmd.context import CommandContext
 from debputy.commands.debputy_cmd.output import _output_styling, OutputStylingBase
 from debputy.filesystem_scan import FSROOverlay
 from debputy.linting.lint_util import (
-    LinterImpl,
     LintReport,
     LintStateImpl,
     FormatterImpl,
     TermLintReport,
     LintDiagnosticResultState,
+    AsyncLinterImpl,
 )
 from debputy.lsp.diagnostics import DiagnosticData
 from debputy.lsp.lsp_debian_changelog import _lint_debian_changelog
@@ -106,7 +106,7 @@ class LintContext:
         path: str,
         content: str,
         lines: List[str],
-        lint_implementation: Optional[LinterImpl],
+        lint_implementation: Optional[AsyncLinterImpl],
     ) -> LintStateImpl:
         return LintStateImpl(
             self.plugin_feature_set,
@@ -197,7 +197,7 @@ def initialize_lint_report(context: CommandContext) -> LintReport:
     raise AssertionError(f"Missing case for lint_report_format: {lint_report_format}")
 
 
-def perform_linting(context: CommandContext) -> None:
+async def perform_linting(context: CommandContext) -> None:
     parsed_args = context.parsed_args
     if not parsed_args.spellcheck:
         disable_spellchecking()
@@ -209,7 +209,7 @@ def perform_linting(context: CommandContext) -> None:
         filename = f"./{name_stem}"
         if not os.path.isfile(filename):
             continue
-        perform_linting_of_file(
+        await perform_linting_of_file(
             lint_context,
             filename,
             name_stem,
@@ -410,7 +410,7 @@ def _exit_with_lint_code(lint_report: LintReport) -> NoReturn:
     sys.exit(0)
 
 
-def perform_linting_of_file(
+async def perform_linting_of_file(
     lint_context: LintContext,
     filename: str,
     file_format: str,
@@ -424,7 +424,7 @@ def perform_linting_of_file(
         text = fd.read()
 
     if auto_fixing_enabled:
-        _auto_fix_run(
+        await _auto_fix_run(
             lint_context,
             filename,
             text,
@@ -432,7 +432,7 @@ def perform_linting_of_file(
             lint_report,
         )
     else:
-        _diagnostics_run(
+        await _diagnostics_run(
             lint_context,
             filename,
             text,
@@ -487,11 +487,11 @@ def _is_non_interactive_auto_fix_allowed(diagnostic: Diagnostic) -> bool:
     return diag_data is None or diag_data.get("enable_non_interactive_auto_fix", True)
 
 
-def _auto_fix_run(
+async def _auto_fix_run(
     lint_context: LintContext,
     filename: str,
     text: str,
-    linter: LinterImpl,
+    linter: AsyncLinterImpl,
     lint_report: LintReport,
 ) -> None:
     another_round = True
@@ -506,7 +506,7 @@ def _auto_fix_run(
         lines,
         linter,
     )
-    current_issues = lint_state.gather_diagnostics()
+    current_issues = await lint_state.gather_diagnostics()
     issue_count_start = len(current_issues) if current_issues else 0
     while another_round and current_issues:
         another_round = False
@@ -652,17 +652,17 @@ def _auto_fix_run(
             )
 
 
-def _diagnostics_run(
+async def _diagnostics_run(
     lint_context: LintContext,
     filename: str,
     text: str,
-    linter: LinterImpl,
+    linter: AsyncLinterImpl,
     lint_report: LintReport,
 ) -> None:
     lines = text.splitlines(keepends=True)
     lint_state = lint_context.state_for(filename, text, lines, linter)
     with lint_report.line_state(lint_state):
-        issues = lint_state.gather_diagnostics()
+        issues = await lint_state.gather_diagnostics()
         for diagnostic in issues:
             actions = provide_standard_quickfixes_from_diagnostics_lint(
                 CodeActionParams(
