@@ -2,18 +2,14 @@ import re
 from typing import (
     Union,
     Sequence,
-    Tuple,
     Optional,
     List,
-    Dict,
 )
 
 from debputy.linting.lint_util import LintState
 from debputy.lsp.debputy_ls import DebputyLanguageServer
 from debputy.lsp.lsp_debian_control_reference_data import (
-    Deb822KnownField,
     Dep5FileMetadata,
-    StanzaMetadata,
 )
 from debputy.lsp.lsp_features import (
     lint_diagnostics,
@@ -32,26 +28,17 @@ from debputy.lsp.lsp_generic_deb822 import (
     deb822_hover,
     deb822_folding_ranges,
     deb822_semantic_tokens_full,
-    deb822_token_iter,
     deb822_format_file,
-)
-from debputy.lsp.quickfixes import (
-    propose_correct_text_quick_fix,
+    scan_for_syntax_errors_and_token_level_diagnostics,
 )
 from debputy.lsp.vendoring._deb822_repro import (
     Deb822FileElement,
     Deb822ParagraphElement,
 )
-from debputy.lsp.vendoring._deb822_repro.parsing import (
-    Deb822KeyValuePairElement,
-)
 from debputy.lsprotocol.types import (
-    Range,
     CompletionItem,
     CompletionList,
     CompletionParams,
-    DiagnosticRelatedInformation,
-    Location,
     HoverParams,
     Hover,
     TEXT_DOCUMENT_CODE_ACTION,
@@ -63,7 +50,6 @@ from debputy.lsprotocol.types import (
     TextEdit,
     DocumentFormattingParams,
 )
-from debputy.util import detect_possible_typo
 
 try:
     from debputy.lsp.vendoring._deb822_repro.locatable import (
@@ -119,61 +105,6 @@ def _debian_copyright_folding_ranges(
     return deb822_folding_ranges(ls, params, _DEP5_FILE_METADATA)
 
 
-def _scan_for_syntax_errors_and_token_level_diagnostics(
-    deb822_file: Deb822FileElement,
-    lint_state: LintState,
-) -> int:
-    first_error = len(lint_state.lines) + 1
-    spell_checker = lint_state.spellchecker()
-    for (
-        token,
-        start_line,
-        start_offset,
-        end_line,
-        end_offset,
-    ) in deb822_token_iter(deb822_file.iter_tokens()):
-        if token.is_error:
-            first_error = min(first_error, start_line)
-            start_pos = TEPosition(
-                start_line,
-                start_offset,
-            )
-            end_pos = TEPosition(
-                end_line,
-                end_offset,
-            )
-            token_range = TERange.between(start_pos, end_pos)
-            lint_state.emit_diagnostic(
-                token_range,
-                "Syntax error",
-                "error",
-                "debputy",
-            )
-        elif token.is_comment:
-            for word, col_pos, end_col_pos in spell_checker.iter_words(token.text):
-                corrections = spell_checker.provide_corrections_for(word)
-                if not corrections:
-                    continue
-                start_pos = TEPosition(
-                    start_line,
-                    col_pos,
-                )
-                end_pos = TEPosition(
-                    start_line,
-                    end_col_pos,
-                )
-                word_range = TERange.between(start_pos, end_pos)
-                lint_state.emit_diagnostic(
-                    word_range,
-                    f'Spelling "{word}"',
-                    "spelling",
-                    "debputy",
-                    quickfixes=[propose_correct_text_quick_fix(c) for c in corrections],
-                    enable_non_interactive_auto_fix=False,
-                )
-    return first_error
-
-
 def _looks_like_a_dep5_file(
     deb822_file: Deb822FileElement,
     stanzas: List[Deb822ParagraphElement],
@@ -192,20 +123,22 @@ def _looks_like_a_dep5_file(
 
 
 @lint_diagnostics(_DISPATCH_RULE)
-def _lint_debian_copyright(lint_state: LintState) -> None:
+async def _lint_debian_copyright(lint_state: LintState) -> None:
     deb822_file = lint_state.parsed_deb822_file_content
     stanzas = list(deb822_file)
 
     if not _looks_like_a_dep5_file(deb822_file, stanzas):
         return
 
-    first_error = _scan_for_syntax_errors_and_token_level_diagnostics(
+    first_error = await scan_for_syntax_errors_and_token_level_diagnostics(
         deb822_file,
         lint_state,
     )
     header_stanza, files_stanza, _ = _DEP5_FILE_METADATA.stanza_types()
 
-    for paragraph_no, paragraph in enumerate(stanzas, start=1):
+    async for paragraph_no, paragraph in lint_state.slow_iter(
+        enumerate(stanzas, start=1)
+    ):
         paragraph_pos = paragraph.position_in_file()
         if paragraph_pos.line_position >= first_error:
             break
@@ -224,7 +157,7 @@ def _lint_debian_copyright(lint_state: LintState) -> None:
         else:
             break
 
-        stanza_metadata.stanza_diagnostics(
+        await stanza_metadata.stanza_diagnostics(
             deb822_file,
             paragraph,
             paragraph_pos,
@@ -261,11 +194,11 @@ def _debian_copyright_on_save_formatting(
 
 
 @lsp_semantic_tokens_full(_DISPATCH_RULE)
-def _debian_copyright_semantic_tokens_full(
+async def _debian_copyright_semantic_tokens_full(
     ls: "DebputyLanguageServer",
     request: SemanticTokensParams,
 ) -> Optional[SemanticTokens]:
-    return deb822_semantic_tokens_full(
+    return await deb822_semantic_tokens_full(
         ls,
         request,
         _DEP5_FILE_METADATA,
