@@ -99,7 +99,7 @@ lsp_standard_handler(_DISPATCH_RULE, TEXT_DOCUMENT_WILL_SAVE_WAIT_UNTIL)
 
 
 @lint_diagnostics(_DISPATCH_RULE)
-def _lint_debian_debputy_manifest(lint_state: LintState) -> None:
+async def _lint_debian_debputy_manifest(lint_state: LintState) -> None:
     lines = lint_state.lines
     try:
         content = MANIFEST_YAML.load("".join(lines))
