@@ -494,7 +494,7 @@ def root_object_parser() -> DispatchingObjectParser:
 
 
 @lint_diagnostics(_DISPATCH_RULE)
-def _lint_debian_upstream_metadata(
+async def _lint_debian_upstream_metadata(
     lint_state: LintState,
 ) -> None:
     lines = lint_state.lines
