@@ -241,7 +241,7 @@ def is_after(position: types.Position, lc_pos: Tuple[int, int]) -> bool:
     return False
 
 
-def word_range_at_position(
+def error_range_at_position(
     lines: List[str],
     line_no: int,
     char_offset: int,
@@ -249,15 +249,25 @@ def word_range_at_position(
     line = lines[line_no]
     line_len = len(line)
     start_idx = char_offset
-    end_idx = char_offset
+    end_idx = start_idx
+
+    if line[start_idx].isspace():
+
+        def _check(x: str) -> bool:
+            return not x.isspace()
+
+    else:
+
+        def _check(x: str) -> bool:
+            return x.isspace()
 
     for i in range(end_idx, line_len):
         end_idx = i
-        if line[i].isspace():
+        if _check(line[i]):
             break
 
     for i in range(start_idx, -1, -1):
-        if i > 0 and line[i].isspace():
+        if i > 0 and _check(line[i]):
             break
         start_idx = i
 
@@ -328,7 +338,7 @@ def insert_complete_marker_snippet(
 
 
 def yaml_key_range(
-    key: str,
+    key: Optional[str],
     line: int,
     col: int,
 ) -> "TERange":
