@@ -7,7 +7,6 @@ from typing import (
     Sequence,
     Callable,
     Iterable,
-    Literal,
     Any,
     Self,
     TYPE_CHECKING,
@@ -24,12 +23,22 @@ LSP_DATA_DOMAIN = "debputy-lsp-data"
 
 
 def format_comp_item_synopsis_doc(
-    usage_hint: Optional[UsageHint], synopsis_doc: str, is_deprecated: bool
+    usage_hint: Optional[UsageHint],
+    synopsis_doc: Optional[str],
+    is_deprecated: bool,
 ) -> str:
     if is_deprecated:
-        return f"[OBSOLETE]: {synopsis_doc}"
+        return (
+            f"[OBSOLETE]: {synopsis_doc}"
+            if synopsis_doc is not None and not synopsis_doc.isspace()
+            else f"[OBSOLETE]"
+        )
     if usage_hint is not None:
-        return f"[{usage_hint.upper()}]: {synopsis_doc}"
+        return (
+            f"[{usage_hint.upper()}]: {synopsis_doc}"
+            if synopsis_doc is not None and not synopsis_doc.isspace()
+            else f"[{usage_hint.upper()}]"
+        )
     return synopsis_doc
 
 
@@ -42,7 +51,14 @@ class Keyword:
     is_obsolete: bool = False
     replaced_by: Optional[str] = None
     is_exclusive: bool = False
-    sort_text: Optional[str] = None
+    sort_text: Optional[
+        Union[
+            str,
+            Callable[
+                ["Keyword", "LintState", Sequence[Deb822ParagraphElement], str], str
+            ],
+        ]
+    ] = None
     usage_hint: Optional[UsageHint] = None
     can_complete_keyword_in_stanza: Optional[
         Callable[[Iterable[Deb822ParagraphElement]], bool]
@@ -56,6 +72,24 @@ class Keyword:
     def is_deprecated(self) -> bool:
         return self.is_obsolete or self.replaced_by is not None
 
+    def resolve_sort_text(
+        self,
+        lint_state: "LintState",
+        stanza_parts: Sequence[Deb822ParagraphElement],
+        value_being_completed: str,
+    ) -> Optional[str]:
+        sort_text = self.sort_text
+        if sort_text is None:
+            return None
+        if not isinstance(sort_text, str):
+            return sort_text(
+                self,
+                lint_state,
+                stanza_parts,
+                value_being_completed,
+            )
+        return sort_text
+
     def is_keyword_valid_completion_in_stanza(
         self,
         stanza_parts: Sequence[Deb822ParagraphElement],
