@@ -49,7 +49,13 @@ from debputy.plugin.api.spec import (
 from debputy.plugin.plugin_state import run_in_context_of_plugin
 from debputy.substitution import Substitution
 from debputy.types import EnvironmentModification
-from debputy.util import run_build_system_command, _debug_log, _info, _warn
+from debputy.util import (
+    run_build_system_command,
+    _debug_log,
+    _info,
+    _warn,
+    generated_root_directory,
+)
 
 if TYPE_CHECKING:
     from debputy.build_support.build_context import BuildContext
@@ -424,9 +430,16 @@ class BuildSystemRule(BuildRule):
     ) -> str:
         build_dir = self.build_directory
         source_dir = self.source_directory
+
+        if path_in_source_dir is None:
+            source_path = source_dir
+        else:
+            source_path = os.path.join(source_dir, path_in_source_dir)
+
         if build_dir == source_dir:
-            return path_in_source_dir
-        return os.path.relpath(os.path.join(source_dir, path_in_source_dir), build_dir)
+            return source_path
+
+        return os.path.relpath(source_path, build_dir)
 
     @final
     @property
@@ -488,6 +501,8 @@ class StepBasedBuildSystemRule(BuildSystemRule):
         # relative would have at least one known issue.
         abs_dest_dir = os.path.abspath(dest_dir)
         self.install_impl(context, manifest, abs_dest_dir, **kwargs)
+        if os.path.isdir(abs_dest_dir):
+            generated_root_directory(abs_dest_dir)
 
     def before_first_impl_step(
         self,
