@@ -322,7 +322,15 @@ def print_command(
         cwd=cwd,
         env_mod=env_mod,
     )
+    global _STDOUT_HANDLER
+    handler = _STDOUT_HANDLER
+    if handler is not None:
+        handler.flush()
+    # Ensure command is output immediately so it is hanging after its output.
+    # TODO: This should `file` in case something in debputy redirects stdout
+    # (nothing does that for now)
     print(f"   {rendered_cmd}")
+    sys.stdout.flush()
 
 
 def run_command(
