@@ -732,6 +732,29 @@ def test_dctrl_lint_synopsis_too_short(line_linter: LintWrapper) -> None:
     assert f"{issue.range}" == "11:13-11:18"
     assert issue.severity == DiagnosticSeverity.Warning
 
+    # Substvars are exempt
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Section: devel
+    Priority: optional
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Maintainer: Jane Developer <jane@example.com>
+    Build-Depends: debhelper-compat (= 13)
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    Depends: bar, baz
+    Description: ${{source:Synopsis}}
+     ${{source:Extended-Description}}
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert not diagnostics
+
 
 def test_dctrl_lint_description_line_too_long(line_linter: LintWrapper) -> None:
     lines = textwrap.dedent(
@@ -1588,6 +1611,15 @@ def test_dctrl_duplicate_key(line_linter: LintWrapper) -> None:
     assert issue.message == msg
     assert f"{issue.range}" == "27:0-27:10"
     assert issue.severity == DiagnosticSeverity.Error
+    assert diag_range_to_text(lines, issue.range) == "Multi-Arch"
+
+    related = issue.related_information
+    assert related is not None
+    assert len(related) == 1
+    orig_definition = related[0]
+    assert orig_definition.message == "First definition of Multi-Arch"
+    assert f"{orig_definition.location.range}" == "21:0-21:10"
+    assert diag_range_to_text(lines, orig_definition.location.range) == "Multi-Arch"
 
 
 def test_dctrl_lint_homepage(
@@ -1953,7 +1985,7 @@ def test_spellcheck_ignore_package_names(
     assert not diagnostics
 
 
-def test_field_in_wrong_staza(line_linter: LintWrapper) -> None:
+def test_field_in_wrong_stanza(line_linter: LintWrapper) -> None:
     lines = textwrap.dedent(
         f"""\
     Source: foo
@@ -1984,3 +2016,91 @@ def test_field_in_wrong_staza(line_linter: LintWrapper) -> None:
     assert issue.message == msg
     assert f"{issue.range}" == f"10:0-10:12"
     assert issue.severity == DiagnosticSeverity.Error
+
+
+def test_dup_dependency(line_linter: LintWrapper) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Section: devel
+    Priority: optional
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Maintainer: Jane Developer <jane@example.com>
+    Build-Depends: debhelper-compat (= 13)
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: all
+    Depends: bar (>= 1),
+    # Duplicate
+      bar,
+    # Not a duplicate
+      bar (<< 2~),
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 1
+    issue = diagnostics[0]
+
+    msg = "Duplicate relationship. Merge with the previous relationship"
+    assert issue.message == msg
+    assert f"{issue.range}" == "12:2-12:5"
+    assert issue.severity == DiagnosticSeverity.Warning
+    assert diag_range_to_text(lines, issue.range) == "bar"
+    assert issue.related_information and len(issue.related_information) == 1
+    related_info = issue.related_information[0]
+    assert related_info.message == "The previous definition"
+    assert f"{related_info.location.range}" == "10:9-10:19"
+    assert diag_range_to_text(lines, related_info.location.range) == "bar (>= 1)"
+
+
+def test_dup_dependency_arch_qual_fp(line_linter: LintWrapper) -> None:
+    lines = textwrap.dedent(
+        f"""\
+    Source: foo
+    Section: devel
+    Priority: optional
+    Standards-Version: {CURRENT_STANDARDS_VERSION}
+    Maintainer: Jane Developer <jane@example.com>
+    Build-Depends:
+     debhelper-compat (= 13),
+    # These should not trigger a warning
+     libssl-dev,
+     libssl-dev:native,
+    # These should however,
+     libfoo-dev:native,
+     libfoo-dev:any,
+    Homepage: https://example.com
+
+    Package: foo
+    Architecture: any
+    Description: some short synopsis
+     A very interesting description
+     with a valid synopsis
+     .
+     Just so be clear, this is for a test.
+    """
+    ).splitlines(keepends=True)
+
+    diagnostics = line_linter(lines)
+    print(diagnostics)
+    assert diagnostics and len(diagnostics) == 1
+    issue = diagnostics[0]
+
+    msg = "Duplicate relationship. Merge with the previous relationship"
+    assert issue.message == msg
+    assert f"{issue.range}" == "12:1-12:15"
+    assert issue.severity == DiagnosticSeverity.Warning
+    assert diag_range_to_text(lines, issue.range) == "libfoo-dev:any"
+    assert issue.related_information and len(issue.related_information) == 1
+    related_info = issue.related_information[0]
+    assert related_info.message == "The previous definition"
+    assert f"{related_info.location.range}" == "11:1-11:18"
+    assert diag_range_to_text(lines, related_info.location.range) == "libfoo-dev:native"
