@@ -19,6 +19,7 @@ else:
 @dataclasses.dataclass(slots=True, frozen=True)
 class ResolvedSemanticToken:
     range: types.Range
+    value: str
     token_name: str
     modifiers: FrozenSet[str] = frozenset()
 
@@ -26,7 +27,7 @@ class ResolvedSemanticToken:
 def resolved_semantic_token(
     line_no: int,
     col_start: int,
-    token_len: int,
+    value: str,
     token_type: str,
     *,
     token_modifiers: FrozenSet[str] = frozenset(),
@@ -39,9 +40,10 @@ def resolved_semantic_token(
             ),
             types.Position(
                 line_no,
-                col_start + token_len,
+                col_start + len(value),
             ),
         ),
+        value,
         token_type,
         token_modifiers,
     )
@@ -99,6 +101,7 @@ def put_doc_no_cursor(
 
 
 def resolve_semantic_tokens(
+    lines: List[str],
     token_result: Optional[types.SemanticTokens],
 ) -> Optional[List[ResolvedSemanticToken]]:
     if token_result is None:
@@ -118,11 +121,13 @@ def resolve_semantic_tokens(
             not modifier_codes
         ), "TODO: Modifiers not supported (no modifiers defined)"
 
+        value = lines[current_line][current_col : current_col + token_len]
+
         resolved_tokens.append(
             resolved_semantic_token(
                 current_line,
                 current_col,
-                token_len,
+                value,
                 token_types[token_code],
             ),
         )
