@@ -48,6 +48,8 @@ def test_debputy_packager_provided_files():
         "tmpfiles",
         "sysusers",
         "bash-completion",
+        "fish-completion",
+        "zsh-completion",
         "pam",
         "ppp.ip-up",
         "ppp.ip-down",
@@ -878,7 +880,9 @@ def test_debputy_manifest_variables() -> None:
         "_DEBPUTY_INTERNAL_NON_BINNMU_SOURCE",
         "_DEBPUTY_SND_SOURCE_DATE_EPOCH",
         "path:BASH_COMPLETION_DIR",
+        "path:FISH_COMPLETION_DIR",
         "path:GNU_INFO_DIR",
+        "path:ZSH_COMPLETION_DIR",
         "token:CLOSE_CURLY_BRACE",
         "token:DOUBLE_CLOSE_CURLY_BRACE",
         "token:DOUBLE_OPEN_CURLY_BRACE",
