@@ -4,6 +4,7 @@ from typing import Callable, Optional, List, Tuple, Sequence
 
 import pytest
 
+from debputy.commands.debputy_cmd.output import no_fancy_output
 from debputy.dh_migration.migrators import Migrator
 from debputy.dh_migration.migrators_impl import (
     migrate_tmpfile,
@@ -23,6 +24,7 @@ from debputy.dh_migration.migrators_impl import (
     migrate_dh_installsystemd_files,
     detect_obsolete_substvars,
     detect_dh_addons_zz_debputy_rrr,
+    migrate_shell_completions,
 )
 from debputy.dh_migration.models import (
     FeatureMigration,
@@ -99,7 +101,7 @@ def run_migrator(
     *,
     migration_target=INTEGRATION_MODE_DH_DEBPUTY,
 ) -> FeatureMigration:
-    feature_migration = FeatureMigration(migrator.__name__)
+    feature_migration = FeatureMigration(migrator.__name__, no_fancy_output())
     migrator(
         path,
         manifest,
@@ -1308,7 +1310,7 @@ def test_detect_obsolete_substvars(
     )
     msg = (
         "The following relationship substitution variables can be removed from foo:"
-        " ${misc:Depends}, ${shlibs:Depends}, ${so:Depends}"
+        " ${misc:Depends}, ${shlibs:Depends}, ${so:Depends} (Note: https://bugs.debian.org/1067653)"
     )
     assert migration.anything_to_do
     assert migration.warnings == [msg]
@@ -1356,7 +1358,7 @@ def test_detect_obsolete_substvars_remove_field(
     )
     msg = (
         "The following relationship fields can be removed from foo: Pre-Depends."
-        "  (The content in them would be applied automatically.)"
+        "  (The content in them would be applied automatically. Note: https://bugs.debian.org/1067653)"
     )
     assert migration.anything_to_do
     assert migration.warnings == [msg]
@@ -1406,7 +1408,7 @@ def test_detect_obsolete_substvars_remove_field_essential(
     )
     msg = (
         "The following relationship fields can be removed from foo: Pre-Depends."
-        "  (The content in them would be applied automatically.)"
+        "  (The content in them would be applied automatically. Note: https://bugs.debian.org/1067653)"
     )
     assert migration.anything_to_do
     assert migration.warnings == [msg]
@@ -1770,3 +1772,80 @@ def test_migrate_bash_completion_file(
         expected_manifest_content,
         expected_renamed_paths=expected_renames,
     )
+
+
+def test_migrate_fish_completions_file_completion_file(
+    manifest_parser_pkg_foo_factory: Callable[[], YAMLManifestParser],
+    accept_no_migration_issues: AcceptableMigrationIssues,
+) -> None:
+    dh_config_content = textwrap.dedent(
+        """\
+        # I have no idea how a fish-completion file looks.
+        something something we win
+    """
+    )
+    dh_config_name = "fish-completions"
+    fs = build_virtual_file_system(
+        [
+            DEBIAN_DIR_ENTRY,
+            virtual_path_def(
+                dh_config_name,
+                fs_path=f"/nowhere/debian/{dh_config_name}",
+                content=dh_config_content,
+            ),
+        ]
+    )
+    migration = run_migrator(
+        migrate_shell_completions,
+        fs,
+        manifest_parser_pkg_foo_factory().build_manifest(),
+        accept_no_migration_issues,
+    )
+    assert migration.rename_paths_on_success == [
+        ("/nowhere/debian/fish-completions", "debian/foo.fish-completion"),
+    ]
+    assert not migration.remove_paths_on_success
+    assert not migration.warnings
+    assert not migration.required_plugins
+
+
+def test_migrate_zsh_completions_file_list(
+    manifest_parser_pkg_foo_factory: Callable[[], YAMLManifestParser],
+    accept_no_migration_issues: AcceptableMigrationIssues,
+) -> None:
+    dh_config_content = textwrap.dedent(
+        """\
+        foo/*
+        bar baz
+        debian/bar-completion bar
+        debian/foo-completion foo
+        debian/*.cmpl
+    """
+    )
+    expected_manifest_content = textwrap.dedent(
+        """\
+            manifest-version: '0.1'
+            installations:
+            - install:
+                sources:
+                - foo/*
+                - debian/*.cmpl
+                dest-dir: '{{path:ZSH_COMPLETION_DIR}}'
+            - install:
+                source: bar
+                as: '{{path:ZSH_COMPLETION_DIR}}/baz'
+    """
+    )
+    expected_renames = [
+        ("debian/bar-completion", "debian/foo.bar.zsh-completion"),
+        ("debian/foo-completion", "debian/foo.zsh-completion"),
+    ]
+    _verify_migrator_generates_parsable_manifest(
+        migrate_shell_completions,
+        manifest_parser_pkg_foo_factory,
+        accept_no_migration_issues,
+        "zsh-completions",
+        dh_config_content,
+        expected_manifest_content,
+        expected_renamed_paths=expected_renames,
+    )
